package com.knauf.ejb.kuchenzutat;

import java.rmi.RemoteException;
import javax.ejb.EJBLocalObject;

/**
 * Local-Interface der Kuchen-Zutat.
 * Darf kein Remote-Interface sein, da in beide Richtungen (von Kuchen zu Zutat und
 * von Zutat zu Kuchen) referenziert werden kann.
 * 
 * @author  Wolfgang Knauf
 */

public interface LocalZutat extends EJBLocalObject
{
  /**Abrufen der Zutat-ID.
   * Es gibt keine Set-Methode im LocalInterface, denn dies wrde keinen Sinn machen, und das Deploytool
   * meckert.
   * @return Die aktuelle ID.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public Integer getId() throws RemoteException;

  /**Abrufen des Zutat-Namens.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public String getZutatName() throws RemoteException;

  /**Setzen des Zutat-Namens.
   * @param str_Name Neuer Name.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setZutatName(String str_Name) throws RemoteException;

  /**Abrufen der Menge (als String)
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public String getMenge() throws RemoteException;

  /**Setzen der menge als String
   * @param str_Menge Neue Menge
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public void setMenge(String str_Menge) throws RemoteException;

  /**Abrufen des Kuchens, zu dem die Zutat gehrt.
   * @return Der Kuchen der Zutat.
   */
  public LocalKuchen getKuchen() throws RemoteException;
}